import logging


def adjust_logger():
    logger = logging.getLogger()
    logger_handler = logging.StreamHandler()
    logger.addHandler(logger_handler)
    logger_handler.setFormatter(logging.Formatter("\n%(levelname)s: %(message)s"))
    logger.setLevel(logging.INFO)
    return logger


def get_log_level(log_level_str):
    if log_level_str == "error":
        return logging.ERROR
    if log_level_str == "info":
        return logging.INFO
    if log_level_str == "debug":
        return logging.DEBUG
    return logging.ERROR



import os
from setuptools import setup, find_packages

this_directory = os.path.abspath(os.path.dirname(__file__))


def read_file(path):
    with open(os.path.join(this_directory, path), encoding="utf-8") as f:
        return f.read()


long_description = read_file("README.md")

setup(
    name="hashdir",
    version=0.12,
    url="https://github.com/fcivaner/hashdir",
    description="A command line tool to calculate hash of directory"
    " trees using various hash algorithms.",
    description_content_type="text/markdown",
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords="hash imohash md5",
    author="Fırat Civaner",
    author_email="fcivaner@gmail.com",
    license="MIT License",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points={"console_scripts": ["hashdir=hashdir.__main__:main"]},
    install_requires=["imohash"],
)
